import type ItMigration from "./ItMigration";
import QueryBuilder from "./QueryBuilder";
export type SQLiteDatabase = {
    close(): () => void;
    transaction: (tx: any) => void;
};
export type Payload = {
    rows: {
        item(i: number): any;
        raw(): any[];
        length: number;
    };
    rowsAffected: number;
    insertId?: number;
};
/**
 * Resultado de los querys
 */
export type ResultSet = {
    insertId?: number;
    rowsAffected: number;
    rows: any[];
};
/**
 * Administra la base de datos.
 */
export default class DB {
    private static _instances;
    name: string;
    sqlite?: SQLiteDatabase | null;
    /**
     * @param {string} name nombre de la db
     */
    constructor(name: string);
    /**
     * Abre la base de datos
     *
     * @param {string} name nombre de la db
     * @returns {DB} database
     */
    static get(name: string): DB;
    /**
     * Abre la base de datos
     *
     * @param {string} name nombre de la db
     * @returns {DB} database
     */
    static open(name: string): Promise<DB>;
    /**
     * Abre la base de datos
     * @returns {SQLiteDatabase}
     */
    open(): Promise<SQLiteDatabase>;
    /**
     * Cierra la db
     */
    close(): Promise<void>;
    /**
     * Ejecuta sentecias sql.
     *
     * @param {string[]} sql sentencias
     * @param {any[][]} params parametross
     *
     * @returns {Payload[]} resultados
     */
    executeBulkTransaction(sqls: string[], params: any[][]): Promise<Payload[]>;
    /**
     * Ejecuta sentecias sql.
     *
     * @param {string} sql sentencia
     * @param {any[]} params parametros
     *
     * @returns {Payload} resultado
     */
    executeTransaction(sql: string, params?: any[]): Promise<Payload>;
    /**
     * Ejecuta sentecias sql.
     *
     * @param {string[]} sql sentencias
     * @param {any[][]} params parametross
     *
     * @returns {ResultSet[]} resultados
     */
    executeBulkSql(sqls: string[], params: any[][]): Promise<ResultSet[]>;
    /**
     * Ejecuta sentecias sql.
     *
     * @param {string} sql sentencia
     * @param {any[]} params parametros
     *
     * @returns {ResultSet} resultado
     */
    executeSql(sql: string, params?: any[]): Promise<ResultSet>;
    /**
     * Obtiene el numero de version de la db
     */
    getVersion(): Promise<number>;
    /**
     * Establece la versión de la base de datos.
     * @param {int} version la nueva versión de la base de datos
     */
    setVersion(version: number): Promise<void>;
    /**
     * Inicializa el scheme de la base de datos.
     */
    migrate(migration: ItMigration, version: number): Promise<void>;
    /**
     * Obtiene un QueryBuilder
     *
     * @param tableName nombre de la tabla
     * @returns
     */
    table(tableName: string): QueryBuilder;
}
//# sourceMappingURL=DB.d.ts.map